@@ -1,17 +1,21 @@
-#!/usr/bin/perl -X
+#!/usr/bin/perl
 package AI::MicroStructure;
 use strict;
 use warnings;
-use Cwd;
 use Carp;
 use Digest::MD5 qw(md5 md5_hex md5_base64);
+use Digest::SHA1  qw(sha1 sha1_hex sha1_base64);
 use File::Basename;
 use File::Spec;
 use File::Glob;
 use Data::Dumper;
+use AI::MicroStructure::Util;
 
 
-our $VERSION = '0.014';
+our $absstructdir = "";
+our $structdir = "";
+our @CWD=();
+our $VERSION = '0.015';
 our $Structure = 'any'; # default structure
 our $CODESET = 'utf8';
 our $LANG = '';
@@ -26,10 +30,14 @@ our $item="";
 our @items;
 our @a=();
 
-our ($new, $write,$drop) =(0,0,0);
-my @CWD; push @CWD, getcwd();
-our $structdir = "structures";
-our $absstructdir = "$CWD[0]/$structdir";
+
+our ($init,$new,$drop,$available,$lib,
+     $list,$use,$off,$switch,$mirror,
+     $version,$help,$write)  = (0,0,0,0,0,0,0,0,0,0,0,0,0);
+
+eval "\$$_=1; " for @ARGV;
+
+
 
 if( grep{/\bnew\b/} @ARGV ){ $new = 1; cleanArgs("new"); }
 if( grep{/\bwrite\b/} @ARGV ){ $write = 1; cleanArgs("write");  };
@@ -37,24 +45,38 @@ if( grep{/\bdrop\b/} @ARGV ){ $drop = 1; cleanArgs("drop");  };
 
 our $StructureName = $ARGV[0]; # default structure
 our $structure = $ARGV[0]; # default structure
+
+
+
+
+
+
 sub cleanArgs{
-   my ($key) = @_;
-   my @tmp=();
-   foreach(@ARGV){
-   push @tmp,$_ unless($_=~/$key/);}
-   @ARGV=@tmp;
+    my ($key) = @_;
+    my @tmp=();
+    foreach(@ARGV){
+    push @tmp,$_ unless($_=~/$key/);}
+
+    @ARGV=@tmp;
 }
+
+
 # private class method
 sub find_structures {
    my ( $class, @dirs ) = @_;
+
+
    $ALIEN{"base"} =  [map  @$_,
    map  { [ ( fileparse( $_, qr/\.pm$/ ) )[0] => $_ ] }
    map  { File::Glob::bsd_glob(
-   File::Spec->catfile( $_, ($structdir,"*.pm") ) ) } @dirs];
+
+
+   File::Spec->catfile( $_, "*.pm" ) ) } @dirs];
 
    $ALIEN{"store"}=[];
 
 
+
    return @{$ALIEN{"base"}};
 }
 
@@ -81,6 +103,14 @@ sub find_modules {
 }
 
 
+our $micro = AI::MicroStructure->new($Structure);
+$absstructdir = $micro->{state}->{path}->{"cwd/structures"};
+
+
+push @CWD,$absstructdir;
+#push @CWD,$_ for @INC;
+
+
 
 $MICRO{$_} = 0 for keys %{{__PACKAGE__->find_structures(@CWD)} };
 $MODS{$_} = $_ for keys %{{__PACKAGE__->find_modules(@INC)} };
@@ -100,8 +130,6 @@ sub getComponents(){
 
 
 # the functions actually hide an instance
-our $micro = AI::MicroStructure->new($Structure);
-
 # END OF INITIALISATION
 
 # support for use AI::MicroStructure 'stars'
@@ -114,7 +142,9 @@ sub import {
    : @_;
 
    $Structure = $structures[0] if @structures;
-   $micro = AI::MicroStructure->new( $Structure );
+   my $micro = AI::MicroStructure->new( $Structure );
+
+   $absstructdir = $micro->{state}->{path}->{"cwd/structures"};
 
    # export the microname() function
    no strict 'refs';
@@ -141,8 +171,15 @@ sub new {
    # defer croaking until name() is actually called
    my $self = bless { structure => $structure,
                      tools => { @tools }, micro => {}}, $class;
-	return $self;
-   #if(defined($driverarg) && join("" ,@_)  =~/couch|cache|berkeley/){
+
+
+    $self->{state}  =   AI::MicroStructure::Util::load_config();
+    $absstructdir = $self->{state}->{path}->{"cwd/structures"};
+
+#    print Dumper $self;
+
+    return $self;
+
 }
 
 sub _rearrange{
@@ -227,11 +264,13 @@ sub load_data {
 }
 
 
-#fitnes 
+#fitnes
 
 sub fitnes {
-  
-   my ($self, $config,$structure, $config ) = (shift,shift,[$self->structures()]);
+
+    my $self = shift;
+    return sha1_hex($self->structures());
+   ##my ($config,$structure, $config ) = (shift,[$self->structures()]); FIXME
 
 }
 
@@ -255,7 +294,9 @@ sub name {
    if( ! exists $self->{micro}{$structure} ) {
    if( ! $MICRO{$structure} ) {
    eval "require '$absstructdir/$structure.pm';";
-   croak "MicroStructure list $structure does not exist!" if $@;
+   #croak "MicroStructure list $structure does not exist!" if $@;
+
+   use AI::MicroStructure::any;
    $MICRO{$structure} = 1; # loaded
    }
    $self->{micro}{$structure} =
@@ -265,6 +306,8 @@ sub name {
    $self->{micro}{$structure}->name( $count );
 }
 
+
+
 # other methods
 sub structures { wantarray ? ( sort keys %MICRO ) : scalar keys %MICRO }
 sub has_structure { $_[1] ? exists $MICRO{$_[1]} : 0 }
@@ -305,11 +348,17 @@ sub getBundle {
 
    my $self = shift;
 
+    $absstructdir = $self->{state}->{path}->{"cwd/structures"};
 
 
 my @structures = grep { !/^(?:any)/ } AI::MicroStructure->structures;
 my @micros;
 my @search=[];
+
+
+
+
+
 for my $structure (@structures) {
    no strict 'refs';
    eval "require '$absstructdir/$structure.pm';";
@@ -550,7 +599,7 @@ my $self = shift;
 my $StructureName = shift;
 my $data = shift;
 
-
+    $absstructdir = $self->{state}->{path}->{"cwd/structures"};
     $StructureName = lc $self->trim(`micro`) unless($StructureName);
     my $file = "$absstructdir/$StructureName.pm";
     print `mkdir $absstructdir` unless(-d $absstructdir);
@@ -573,26 +622,144 @@ sub drop {
 my $self = shift;
 my $StructureName = shift;
 
-my @file = grep{/$StructureName.pm/}map{File::Glob::bsd_glob(
-File::Spec->catfile( $_, ($structdir,"*.pm") ) )}@CWD;
-my $fh = shift @file;
-if(`ls $fh`)
-{
+my @fh = grep{/$StructureName.pm/}__PACKAGE__->find_structures(@CWD);
+
+
+  if(defined($fh[0]) &&  `ls $fh[0]`)
+  {
+    print  `rm $fh[0]`;
+
+  }else{
+
+   croak "The structure $StructureName does not exist!";
+
+  }
 
-print  `rm $fh`;
-}
-  #push @CWD,$file[1];
 
   return 1;
 }
 
+sub help {
+
+my $self = shift;
+my $usage = << 'EOT';
+
+  #current status
+  #did you create a micro structure yet ?
+  #try something like this
+
+  $ micro new ufo;      # creates a structure called ufo
+
+  $ micro drop ufo;     # deletes the structure called ufo
+
+  $ micro structures;   # shows all structure's you currently have
+
+  #after creation of a structure you can access it in lots of ways
 
 
 
+  $ micro;             # one word of a random structure
+
+  $ micro ufo;         # one word of the ufo structure
+
+  $ micro ufo all;     # all words of the ufo structure
+
+  $ micro ufo 5;       # 5 random words of the ufo structure
+
+  $ micro any 10;      # 10 random words of any structure you have created
+
+
+  $ micro --init        # initializes active memory
+
+  $ micro --export      # export relations from couchdb into git repo and tag data
+
+
+  # oneliners i like to use
+
+  $  for i in `micro structures`; do echo $i; done;       # echos all the structures
+
+  $  for i in `micro ufo all`;   do echo $i; done;       # echos all words in ufo
+
+  $  for i in `micro structures`; do micro all $i; done;  # echos all stuctures all words
+
+  $  for i in `micro ufo all`;   do micro new $i; done;  # new structure for all words in ufo
+
+  $  for i in `micro ufo all`;   do micro-wiki $i; done; # push all words against the wiki plugin dont forget setting user & password in /usr/local/bin/micro-wiki
+
+  ###################################################################################
+  # try to follow the logic combine
+  # your-word=micro new ? ->concept->concepts->relations->node
+
+
+  $ micro new biology
+  $ micro new biological_process
+
+  $ for i in `micro structures`; do
+  $ for y in `micro all $i `; do
+  $ echo "$i=$y";
+  $ micro new $y;
+  $ done
+  $ done
+
+  #!!!!!###Hard cpu to expect ### make sure couch is on   ######  or disable the store methode in micro-wiki and print $doc or consume otherweise
+  # test as single before you loope
+
+  $ micro-wiki ufo
+
+  # proceed
+
+  $ for i in `micro structures`; do
+  $ for y in `micro all $i `; do
+  $ echo "$i=$y";
+  $ micro-wiki $y;
+  $ done
+  $ done
+
+
+EOT
+
+
+
+return $usage;
+
+}
+
+
+BEGIN {
+
+
+}
+
 END{
 
+if($init){}
+if($available){}
+if($lib){}
+if($list){}
+if($use){}
+if($off){}
+if($switch){}
+if($mirror){}
+if($version){
+    printf($VERSION);
+    exit(0);
+}
+
+
+
+if($help) {
+    printf($micro->help());
+    exit(0);
+
+}
+
+
+
+
+
 if($drop == 1) {
    $micro->drop($StructureName);
+   exit 0;
 }
 
 if($new==1){
@@ -786,17 +953,4 @@ __END__
 =head1 SEE ALSO
 
   AI-MicroStructure
-  AI-MicroStructure-Cache
-  AI-MicroStructure-Deamon
-  AI-MicroStructure-Relations
-  AI-MicroStructure-Concept
-  AI-MicroStructure-Data
-  AI-MicroStructure-Driver
-  AI-MicroStructure-Plugin-Pdf
-  AI-MicroStructure-Plugin-Twitter
-  AI-MicroStructure-Plugin-Wiki
-
-
-
-__DATA__
-
+=cut
